@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-01-19'; # DATE
 our $DIST = 'Sah-Schemas-WordList'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of Perl WordList::* module names without the prefix, e.g. ["EN::Enable", "EN::BIP39"]',
@@ -26,7 +26,7 @@ The wildcard syntax supports jokers (`?`, `*`, `**`), brackets (`[abc]`), and
 braces (`{one,two}`). See <pm:Module::List::Wildcard> for more details.
 
 _
-    of => ["perl::wordlist::modname", {req=>1}, {}],
+    of => ["perl::wordlist::modname", {req=>1}],
 
     'x.perl.coerce_rules' => [
         ['From_str_or_array::expand_perl_modname_wildcard', {ns_prefix=>'WordList'}],
@@ -35,7 +35,7 @@ _
     # provide a default completion which is from list of installed perl modules
     'x.element_completion' => ['perl_modname', {ns_prefix=>'WordList'}],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Array of Perl WordList::* module names without the prefix, e.g. ["EN::Enable", "EN::BIP39"]
@@ -52,7 +52,7 @@ Sah::Schema::perl::wordlist::modnames - Array of Perl WordList::* module names w
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::perl::wordlist::modnames (from Perl distribution Sah-Schemas-WordList), released on 2023-01-19.
+This document describes version 0.005 of Sah::Schema::perl::wordlist::modnames (from Perl distribution Sah-Schemas-WordList), released on 2023-01-19.
 
 =head1 SYNOPSIS
 
